@@ -41,10 +41,10 @@ except ImportError:
     vc_version = 0
 
 # The tuple giving the version number.
-version_tuple = (6, 99, 12, 4, vc_version)
+version_tuple = (6, 99, 13, vc_version)
 
 # The name of this version.
-version_name = "We get the job done."
+version_name = "We came in peace."
 
 # A string giving the version number only (7.0.1.123).
 version_only = ".".join(str(i) for i in version_tuple)
@@ -151,6 +151,7 @@ backup_blacklist = {
     "renpy.object",
     "renpy.log",
     "renpy.bootstrap",
+    "renpy.debug",
     "renpy.display",
     "renpy.display.pgrender",
     "renpy.display.scale",
@@ -186,6 +187,7 @@ name_blacklist = {
     "renpy.display.render.IDENTITY",
     "renpy.loader.auto_lock",
     "renpy.display.screen.cprof",
+    "renpy.audio.audio.lock",
     }
 
 
@@ -291,6 +293,7 @@ class Backup():
             mod, field = k
             setattr(mod, field, objects[v])
 
+
 # A backup of the Ren'Py modules after initial import.
 backup = None
 
@@ -328,10 +331,13 @@ def import_all():
 
     import renpy.arguments  # @UnresolvedImport
 
+    import renpy.config
     import renpy.log
 
     import renpy.display
 
+    import renpy.debug
+
     # Should probably be early, as we will add it as a base to serialized things.
     import renpy.object
 
@@ -465,7 +471,6 @@ def import_all():
     import renpy.add_from
     import renpy.dump
 
-    import renpy.config  # depends on lots. @UnresolvedImport
     import renpy.minstore  # depends on lots. @UnresolvedImport
     import renpy.defaultstore  # depends on everything. @UnresolvedImport
 
